@@ -171,10 +171,11 @@ window.init_funcs = {
     key_press_match = function (w)
         w.win:add_signal("key-press", function (_, mods, key)
             -- Match & exec a bind
-            local success, match = pcall(w.hit, w, mods, key)
-            if not success then
-                w:error("In bind call: " .. match)
-            elseif match then
+            local success, match = xpcall(
+                function () return w:hit(mods, key) end,
+                function (err) w:error(debug.traceback(err, 3)) end)
+
+            if success and match then
                 return true
             end
         end)
@@ -281,6 +282,12 @@ window.methods = {
         w:set_input(cmd, opts)
     end,
 
+    -- run command as if typed into the command line
+    run_cmd = function (w, cmd, opts)
+        w:enter_cmd(cmd, opts)
+        w:activate()
+    end,
+
     -- insert a string into the command line at the current cursor position
     insert_cmd = function (w, str)
         if not str then return end
@@ -660,7 +667,7 @@ window.methods = {
         if view then
             local js = string.match(uri, "^javascript:(.+)$")
             if js then
-                return view:eval_js(luakit.uri_decode(js), "(javascript-uri)")
+                return view:eval_js(luakit.uri_decode(js))
             end
             view.uri = uri
         else
@@ -777,6 +784,15 @@ window.methods = {
         end
     end,
 
+    -- For each tab, switches to that tab and calls the given function passing
+    -- it the view contained in the tab.
+    each_tab = function (w, fn)
+        for index = 1, w.tabs:count() do
+            w:goto_tab(index)
+            fn(w.tabs[index])
+        end
+    end,
+
     -- If argument is form-active or root-active, emits signal. Ignores all
     -- other signals.
     emit_form_root_active_signal = function (w, s)
